@@ -12,7 +12,10 @@ use Template::Alloy::Exception;
 use Template::Alloy::Operator qw(play_operator define_operator);
 use Template::Alloy::VMethod  qw(define_vmethod $SCALAR_OPS $FILTER_OPS $LIST_OPS $HASH_OPS $VOBJS);
 
-our $VERSION            = '1.001';
+use vars qw($VERSION);
+BEGIN {
+    $VERSION            = '1.002';
+};
 our $QR_PRIVATE         = qr/^[_.]/;
 our $WHILE_MAX          = 1000;
 our $MAX_EVAL_RECURSE   = 50;
@@ -26,6 +29,8 @@ our $EVAL_CONFIG        = {map {$_ => 1} @CONFIG_COMPILETIME, @CONFIG_RUNTIME};
 our $EXTRA_COMPILE_EXT  = '.sto';
 our $PERL_COMPILE_EXT   = '.pl';
 
+###----------------------------------------------------------------###
+
 our $AUTOROLE = {
     Compile  => [qw(compile_template compile_tree compile_expr)],
     HTE      => [qw(parse_tree_hte param output register_function clear_param query new_file new_scalar_ref new_array_ref new_filehandle)],
@@ -35,7 +40,8 @@ our $AUTOROLE = {
     Tmpl     => [qw(parse_tree_tmpl set_delimiters set_strip set_value set_values parse_string set_dir parse_file loop_iteration fetch_loop_iteration)],
     Velocity => [qw(parse_tree_velocity merge)],
 };
-our $ROLEMAP = { map { my $type = $_; map { ($_ => $type) } @{ $AUTOROLE->{$type} } } keys %$AUTOROLE };
+my $ROLEMAP = { map { my $type = $_; map { ($_ => $type) } @{ $AUTOROLE->{$type} } } keys %$AUTOROLE };
+my %STANDIN = ('Template' => 'TT', 'Template::Toolkit' => 'TT', 'HTML::Template' => 'HTE', 'HTML::Template::Expr' => 'HTE', 'Text::Tmpl' => 'Tmpl');
 
 our $AUTOLOAD;
 sub AUTOLOAD {
@@ -50,20 +56,41 @@ sub AUTOLOAD {
 
 sub can {
     my ($self, $meth) = @_;
-    if (my $type = delete($ROLEMAP->{$meth})) {
-        my $pkg  = __PACKAGE__."::$type";
-        my $file = "$pkg.pm";
-        $file =~ s|::|/|g;
-        require $file;
-
-        no strict 'refs';
-        *{__PACKAGE__."::$_"} = \&{"$pkg\::$_"} for @{ $AUTOROLE->{ $type }};
-    }
+    __PACKAGE__->import($_) if $_ = $ROLEMAP->{$meth};
     return $self->SUPER::can($meth);
 }
 
 sub DESTROY {}
 
+sub import {
+    my $class = shift;
+    foreach my $item (@_) {
+        next if $item =~ /^(load|1)$/i;
+        return $class->import(keys %$AUTOROLE) if lc $item eq 'all';
+
+        my $type;
+        if ($type = $STANDIN{$item}) {
+            (my $file = "$item.pm") =~ s|::|/|g;
+            if (! $INC{$file} || ! $item->isa(__PACKAGE__)) {
+                if ($INC{$file}) { require Carp; Carp::croak("Class $item is already loaded - can't override") }
+                eval "{package $item; our \@ISA = qw(".__PACKAGE__.");}";
+                $INC{$file} = __FILE__;
+                next if ! $AUTOROLE->{$type}; # already imported
+            }
+        }
+        $type ||= $AUTOROLE->{$item} ? $item : $ROLEMAP->{$item} || do { require Carp; Carp::croak("Invalid import option \"$item\"") };
+
+        my $pkg   = __PACKAGE__."::$type";
+        (my $file = "$pkg.pm") =~ s|::|/|g;
+        require $file;
+
+        no strict 'refs';
+        *{__PACKAGE__."::$_"} = \&{"$pkg\::$_"} for @{ $AUTOROLE->{$type} };
+        $AUTOROLE->{$type} = [];
+    }
+    return 1;
+}
+
 ###----------------------------------------------------------------###
 
 sub new {
@@ -833,7 +860,9 @@ sub node_info {
 
 sub get_line_number_by_index {
     my ($self, $doc, $index, $include_char) = @_;
-    return 1 if $index <= 0;
+    if (! $index || $index <= 0) {
+        return $include_char ? (1, 1) : 1;
+    }
 
     my $lines = $doc->{'_line_offsets'} ||= do {
         $doc->{'_content'} ||= $self->slurp($doc->{'_filename'});
